@@ -1,8 +1,8 @@
 // Chip's Workshop - a level editor for Chip's Challenge.
-// Copyright 2008-2009 Christopher Elsby <glarbex@glarbex.com>
+// Copyright 2008-2011 Christopher Elsby <chrise@chrise.me.uk>
 // 
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of version 2 of the GNU General Public License as
+// This program is free software: you can redistribute it and/or modify
+// it under the terms of version 3 of the GNU General Public License as
 // published by the Free Software Foundation.
 // 
 // This program is distributed in the hope that it will be useful,
@@ -11,18 +11,21 @@
 // GNU General Public License for more details.
 // 
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #ifndef CHIPW_APP_H_INCLUDED
 #define CHIPW_APP_H_INCLUDED
 
 #include <wx/app.h>
+#include <wx/event.h>
+#include <set>
 
 class wxDocManager;
 
 namespace ChipW {
 
+class PlayTestManager;
+
 class App : public wxApp {
 public:
     App();
@@ -30,10 +33,20 @@ public:
     virtual void OnInitCmdLine(wxCmdLineParser& parser);
     virtual bool OnCmdLineParsed(wxCmdLineParser& parser);
     virtual int OnExit();
+    // Get the playtest menu manager.
+    PlayTestManager* GetPlayTestManager() const {return playtestmgr;}
+    // Register a temporary file to be deleted on program exit.
+    void RegisterTmpFile(wxString filename) {tmpfiles.insert(filename);}
+    // Unregister a temporary file so that it will not be deleted on program exit.
+    void UnregisterTmpFile(wxString filename) {tmpfiles.erase(filename);}
+    // Deletes and unregisters the given temporary file if it is currently registered.
+    void RemoveTmpFile(wxString filename);
 private:
     void OnCommand(wxCommandEvent& event);
     wxDocManager* docmgr;
+    PlayTestManager* playtestmgr;
     bool autostart;
+    std::set<wxString> tmpfiles;
     DECLARE_EVENT_TABLE()
 };
 
