@@ -1,8 +1,8 @@
 // Chip's Workshop - a level editor for Chip's Challenge.
-// Copyright 2008-2009 Christopher Elsby <glarbex@glarbex.com>
+// Copyright 2008-2011 Christopher Elsby <chrise@chrise.me.uk>
 // 
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of version 2 of the GNU General Public License as
+// This program is free software: you can redistribute it and/or modify
+// it under the terms of version 3 of the GNU General Public License as
 // published by the Free Software Foundation.
 // 
 // This program is distributed in the hope that it will be useful,
@@ -11,8 +11,7 @@
 // GNU General Public License for more details.
 // 
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #ifndef CHIPW_LEVELEDITIDS_H_INCLUDED
 #define CHIPW_LEVELEDITIDS_H_INCLUDED
@@ -33,6 +32,9 @@ enum {
     ID_CLOSEVIEW,
     ID_ROTATE_TILE_ANTICLOCKWISE,
     ID_ROTATE_TILE_CLOCKWISE,
+    ID_PLAYTEST_CONFIG,
+    ID_PLAYTEST_MIN,
+    ID_PLAYTEST_MAX = ID_PLAYTEST_MIN + 8,
 };
 
 }
