@@ -1,8 +1,8 @@
 // Chip's Workshop - a level editor for Chip's Challenge.
-// Copyright 2008-2009 Christopher Elsby <glarbex@glarbex.com>
+// Copyright 2008-2011 Christopher Elsby <chrise@chrise.me.uk>
 // 
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of version 2 of the GNU General Public License as
+// This program is free software: you can redistribute it and/or modify
+// it under the terms of version 3 of the GNU General Public License as
 // published by the Free Software Foundation.
 // 
 // This program is distributed in the hope that it will be useful,
@@ -11,8 +11,7 @@
 // GNU General Public License for more details.
 // 
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "global.h"
 
@@ -28,6 +27,8 @@
 #include "leveleditids.h"
 #include "apppaths.h"
 #include "leveldataobj.h"
+#include "app.h"
+#include "playtestmgr.h"
 #include <wx/statusbr.h>
 #include <wx/splitter.h>
 #include <wx/panel.h>
@@ -52,6 +53,8 @@
 #include <wx/region.h>
 #include <wx/clipbrd.h>
 
+#include <iostream>
+
 namespace ChipW {
 
 class LevelMapWindow : public BufferedScrolledWindow {
@@ -212,7 +215,7 @@ void LevelEditView::OnChangeFilename() {
         if(name)
             title += wxT(" - ") + name;
         if(level != NULL && !level->title.empty())
-            title += wxT(" (") + wxString(level->title.c_str(), wxConvUTF8) + wxT(")");
+            title += wxT(" (") + wxString(level->title.c_str(), wxConvISO8859_1) + wxT(")");
         if(GetFrame()->IsKindOf(CLASSINFO(wxTopLevelWindow)))
             ((wxTopLevelWindow*) GetFrame())->SetTitle(title);
         else
@@ -227,8 +230,12 @@ bool LevelEditView::OnClose(bool delwin) {
     if(mapwin != NULL)
         mapwin->view = NULL;
     mapwin = NULL;
+    if(tilesel != NULL)
+        tilesel->view = NULL;
+    tilesel = NULL;
     levellist = NULL;
     tilelist = NULL;
+    statusbar = NULL;
     delete mapbmp;
     mapbmp = NULL;
     if(delwin && GetFrame() != NULL) {
@@ -322,43 +329,65 @@ void LevelEditView::OnCommand(wxCommandEvent& event) {
     case wxID_PROPERTIES:
         if(level != NULL && doc != NULL && levelset != NULL) {
             LevelPropertiesDialog dlg(GetFrame(), readonly);
-            dlg.title << wxString(level->title.c_str(), wxConvUTF8);
-            dlg.psw << wxString(level->psw.c_str(), wxConvUTF8);
+            dlg.title << wxString(level->title.c_str(), wxConvISO8859_1);
+            dlg.psw << wxString(level->psw.c_str(), wxConvISO8859_1);
             dlg.chips << level->chips;
             dlg.countedchips << level->CountChips();
             dlg.time << level->time;
-            dlg.hint << wxString(level->hint.c_str(), wxConvUTF8);
+            dlg.hint << wxString(level->hint.c_str(), wxConvISO8859_1);
             dlg.levnum << level->levelnumber;
-            dlg.magic << levelset->magic;
+//            dlg.ruleset << levelset->ruleset;
+            dlg.ruleset = levelset->ruleset;
             if(dlg.ShowModal() == wxID_OK && !readonly) {
                 unsigned long ul;
-                std::string title;
-                title = dlg.title.mb_str(wxConvUTF8);
-                std::string psw;
-                psw = dlg.psw.mb_str(wxConvUTF8);
+                std::string title = level->title;
+                {
+                    const wxWX2MBbuf str = dlg.title.mb_str(wxConvISO8859_1);
+                    if(str != NULL)
+                        title = str;
+                    else
+                        wxLogError(wxT("Failed to set level title."));
+                }
+                std::string psw = level->psw;
+                {
+                    const wxWX2MBbuf str = dlg.psw.mb_str(wxConvISO8859_1);
+                    if(str != NULL)
+                        psw = str;
+                    else
+                        wxLogError(wxT("Failed to set level password."));
+                }
                 wxUint16 chips = level->chips;
                 if(dlg.chips.ToULong(&ul) && ul < 65536)
                     chips = ul;
                 else
-                    wxLogWarning(wxT("Failed to set chips required."));
+                    wxLogError(wxT("Failed to set chips required."));
                 wxUint16 time = level->time;
                 if(dlg.time.ToULong(&ul) && ul < 65536)
                     time = ul;
                 else
-                    wxLogWarning(wxT("Failed to set time limit."));
-                std::string hint;
-                hint = dlg.hint.mb_str(wxConvUTF8);
+                    wxLogError(wxT("Failed to set time limit."));
+                std::string hint = level->hint;
+                {
+                    const wxWX2MBbuf str = dlg.hint.mb_str(wxConvISO8859_1);
+                    if(str != NULL)
+                        hint = str;
+                    else
+                        wxLogError(wxT("Failed to set level hint."));
+                }
                 wxUint16 levelnumber = level->levelnumber;
                 if(dlg.levnum.ToULong(&ul) && ul < 65536)
                     levelnumber = ul;
                 else
-                    wxLogWarning(wxT("Failed to set level number."));
-                wxUint32 magic = levelset->magic;
-                if(dlg.magic.ToULong(&ul))
-                    magic = ul;
+                    wxLogError(wxT("Failed to set level number."));
+#if 0
+                wxUint32 ruleset = levelset->ruleset;
+                if(dlg.ruleset.ToULong(&ul))
+                    ruleset = ul;
                 else
-                    wxLogWarning(wxT("Failed to set magic number."));
-                doc->SetLevelProperties(level, title, psw, chips, time, hint, levelnumber, magic);
+                    wxLogError(wxT("Failed to set rule set."));
+#endif
+                wxUint32 ruleset = dlg.ruleset;
+                doc->SetLevelProperties(level, title, psw, chips, time, hint, levelnumber, ruleset);
 #if 0
                 hint.type = LevelUpdateHint::LIST;
                 hint.level = level;
@@ -604,7 +633,19 @@ void LevelEditView::OnCommand(wxCommandEvent& event) {
         Close();
         break;
     default:
-        event.Skip();
+        {
+            PlayTestManager* playtestmgr = wxGetApp().GetPlayTestManager();
+            if(playtestmgr != NULL && playtestmgr->HasId(event.GetId())) {
+                if(levelset != NULL) {
+                    const PlayTestType& playtesttype = playtestmgr->GetTypes()[event.GetId() - playtestmgr->GetIdMin()];
+                    if(!playtesttype.Launch(*levelset, level == NULL ? 1 : level->levelnumber))
+                        wxLogError(wxT("Playtesting failed."));
+                    // If playtesting started successfully, the process object will delete itself when finished.
+                }
+            } else {
+                event.Skip();
+            }
+        }
     }
 }
 
@@ -667,7 +708,13 @@ void LevelEditView::OnUpdateUI(wxUpdateUIEvent& event) {
         event.Check(buttonswap);
         break;
     default:
-        event.Skip();
+        {
+            PlayTestManager* playtestmgr = wxGetApp().GetPlayTestManager();
+            if(playtestmgr != NULL && playtestmgr->HasId(event.GetId()))
+                event.Enable(playtestmgr->IsIdActive(event.GetId()) && levelset != NULL);
+            else
+                event.Skip();
+        }
     }
 }
 
@@ -975,7 +1022,7 @@ void LevelEditView::OnUpdate(wxView* sender, wxObject* hint) {
         wxUint16 i;
         for(i = 0; i < levelset->GetLevelCount(); ++i) {
             lev = levelset->GetLevel(i);
-            choices[i] << lev->levelnumber << wxT(". ") << wxString(lev->title.c_str(), wxConvUTF8);
+            choices[i] << lev->levelnumber << wxT(". ") << wxString(lev->title.c_str(), wxConvISO8859_1);
         }
         levellist->Set(levelset->GetLevelCount(), choices);
         delete[] choices;
@@ -1265,7 +1312,8 @@ bool LevelEditView::DoTileAction(wxUint32 x, wxUint32 y, wxUint32 tile, wxString
         }
         special = (action == wxT("cleartile"));
 #endif
-    } else if(action == wxT("rectselect") || (action == wxT("select") && tile == TOOL_RECTSELECT) && !special) {
+// FIXME: Make sure the line below has correct parenthesisation.
+    } else if((action == wxT("rectselect") || (action == wxT("select") && tile == TOOL_RECTSELECT)) && !special) {
         hadaction = true;
         if(clickx >= 32 || clicky >= 32) {
             clickx = x;
