@@ -1,8 +1,8 @@
 // Chip's Workshop - a level editor for Chip's Challenge.
-// Copyright 2008-2009 Christopher Elsby <glarbex@glarbex.com>
+// Copyright 2008-2011 Christopher Elsby <chrise@chrise.me.uk>
 // 
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of version 2 of the GNU General Public License as
+// This program is free software: you can redistribute it and/or modify
+// it under the terms of version 3 of the GNU General Public License as
 // published by the Free Software Foundation.
 // 
 // This program is distributed in the hope that it will be useful,
@@ -11,8 +11,7 @@
 // GNU General Public License for more details.
 // 
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "global.h"
 
@@ -260,7 +259,7 @@ public:
         wxUint16 time;
         std::string hint;
         wxUint16 levelnumber;
-        wxUint32 magic;
+        wxUint32 ruleset;
     };
     LevelPropertiesCommand(CountedPtr<Level> lev, LevelSetDoc* doc, const Properties& oldprops, const Properties& newprops) : level(lev), document(doc), oldproperties(oldprops), newproperties(newprops) { }
     virtual wxString GetName() const {return wxT("Edit Level Properties");}
@@ -281,7 +280,7 @@ inline bool operator==(const LevelPropertiesCommand::Properties& a, const LevelP
         && a.time == b.time
         && a.hint == b.hint
         && a.levelnumber == b.levelnumber
-        && a.magic == b.magic
+        && a.ruleset == b.ruleset
     ;
 }
 
@@ -299,7 +298,7 @@ bool LevelPropertiesCommand::SetProperties(const Properties& properties) {
     level->time = properties.time;
     level->hint = properties.hint;
     level->levelnumber = properties.levelnumber;
-    levelset->magic = properties.magic;
+    levelset->ruleset = properties.ruleset;
     document->Modify(true);
     LevelUpdateHint hint;
     hint.type = LevelUpdateHint::LIST;
@@ -412,7 +411,7 @@ bool LevelSetDoc::SetLevelMonsters(CountedPtr<Level> level, const std::list<Mons
     return GetCommandProcessor()->Submit(new LevelMonstersCommand(level, this, level->monsters, newmonsters));
 }
 
-bool LevelSetDoc::SetLevelProperties(CountedPtr<Level> level, std::string title, std::string psw, wxUint16 chips, wxUint16 time, std::string hint, wxUint16 levelnumber, wxUint32 magic) {
+bool LevelSetDoc::SetLevelProperties(CountedPtr<Level> level, std::string title, std::string psw, wxUint16 chips, wxUint16 time, std::string hint, wxUint16 levelnumber, wxUint32 ruleset) {
     if(level == NULL)
         return false;
     LevelPropertiesCommand::Properties oldproperties;
@@ -422,7 +421,7 @@ bool LevelSetDoc::SetLevelProperties(CountedPtr<Level> level, std::string title,
     oldproperties.time = level->time;
     oldproperties.hint = level->hint;
     oldproperties.levelnumber = level->levelnumber;
-    oldproperties.magic = levelset.magic;
+    oldproperties.ruleset = levelset.ruleset;
     LevelPropertiesCommand::Properties newproperties;
     newproperties.title = title;
     newproperties.psw = psw;
@@ -430,7 +429,7 @@ bool LevelSetDoc::SetLevelProperties(CountedPtr<Level> level, std::string title,
     newproperties.time = time;
     newproperties.hint = hint;
     newproperties.levelnumber = levelnumber;
-    newproperties.magic = magic;
+    newproperties.ruleset = ruleset;
     if(newproperties == oldproperties)
         return true;
     return GetCommandProcessor()->Submit(new LevelPropertiesCommand(level, this, oldproperties, newproperties));
@@ -439,18 +438,18 @@ bool LevelSetDoc::SetLevelProperties(CountedPtr<Level> level, std::string title,
 bool LevelSetDoc::DoSaveDocument(const wxString& file) {
     wxTempFileOutputStream wxstream(file);
     if(!wxstream.IsOk()) {
-        wxLogError(_("Sorry, could not open this file for saving."));
+        wxLogError(wxT("%s"), _("Sorry, could not open this file for saving."));
         return false;
     }
     {
         owxstream stream(&wxstream);
         if(!SaveObject(stream)) {
-            wxLogError(_("Sorry, could not save this file."));
+            wxLogError(wxT("%s"), _("Sorry, could not save this file."));
             return false;
         }
     }
     if(!wxstream.Commit()) {
-        wxLogError(_("Sorry, could not save this file."));
+        wxLogError(wxT("%s"), _("Sorry, could not save this file."));
         return false;
     }
     return true;
@@ -470,7 +469,7 @@ bool LevelSetDoc::DoOpenDocument(const wxString& file)
         if(LoadObject(stream))
             return true;
     }
-    wxLogError(_("Sorry, could not open this file."));
+    wxLogError(wxT("%s"), _("Sorry, could not open this file."));
     return false;
 }
 
